/*===========================================================================*/
/*   (Init/extend.scm)                                                       */
/*   Bigloo (4.6a)                                                           */
/*   Inria -- Sophia Antipolis (c)       Mon Jan 27 07:45:49 AM CET 2025     */
/*===========================================================================*/
/* COMPILATION: (/home/serrano/prgm/project/bigloo/4.6a/bin/bigloo -q -afile .afile -fsharing -fno-reflection -cc gcc -lib-dir /home/serrano/prgm/project/bigloo/4.6a/lib/bigloo/4.6a -unsafev -gno-error-localization -no-hello -O2 -rm -unsafe -s -stdc -indent Init/extend.scm) */
/* GC selection */
#define THE_GC BOEHM_GC

/* unsafe mode */
#define BIGLOO_UNSAFE 1

/* traces mode */
#define BIGLOO_TRACE 0

/* standard Bigloo include */
#include <bigloo.h>

#ifdef __cplusplus
extern "C"
{
#endif
#ifndef BGL_MODULE_TYPE_DEFINITIONS
#define BGL_MODULE_TYPE_DEFINITIONS
#ifndef BGL_INIT_EXTEND_TYPE_DEFINITIONS
#define BGL_INIT_EXTEND_TYPE_DEFINITIONS
#endif													// BGL_INIT_EXTEND_TYPE_DEFINITIONS
#endif													// BGL_MODULE_TYPE_DEFINITIONS

	static obj_t BGl_requirezd2initializa7ationz75zzinit_extendz00 = BUNSPEC;
	static obj_t BGl_toplevelzd2initzd2zzinit_extendz00(void);
	extern obj_t BGl_internalzd2errorzd2zztools_errorz00(obj_t, obj_t, obj_t);
	static obj_t BGl_genericzd2initzd2zzinit_extendz00(void);
	static obj_t BGl_objectzd2initzd2zzinit_extendz00(void);
	static obj_t BGl_z62loadzd2extendzb0zzinit_extendz00(obj_t, obj_t);
	BGL_IMPORT obj_t BGl_readz00zz__readerz00(obj_t, obj_t);
	BGL_IMPORT obj_t BGl_openzd2inputzd2stringz12z12zz__r4_ports_6_10_1z00(obj_t,
		obj_t, obj_t);
	static obj_t BGl_methodzd2initzd2zzinit_extendz00(void);
	extern obj_t BGl_za2nbzd2errorzd2onzd2passza2zd2zztools_errorz00;
	BGL_IMPORT obj_t string_append(obj_t, obj_t);
	BGL_IMPORT obj_t BGl_errorz00zz__errorz00(obj_t, obj_t, obj_t);
	BGL_EXPORTED_DECL obj_t BGl_modulezd2initializa7ationz75zzinit_extendz00(long,
		char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzengine_paramz00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzengine_passz00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zztools_errorz00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zztools_speekz00(long, char *);
	BGL_IMPORT obj_t BGl_modulezd2initializa7ationz75zz__r4_ports_6_10_1z00(long,
		char *);
	BGL_IMPORT obj_t BGl_modulezd2initializa7ationz75zz__r4_strings_6_7z00(long,
		char *);
	BGL_IMPORT obj_t
		BGl_modulezd2initializa7ationz75zz__r4_pairs_and_lists_6_3z00(long, char *);
	BGL_IMPORT obj_t BGl_modulezd2initializa7ationz75zz__evalz00(long, char *);
	BGL_IMPORT obj_t BGl_modulezd2initializa7ationz75zz__readerz00(long, char *);
	BGL_IMPORT obj_t BGl_modulezd2initializa7ationz75zz__osz00(long, char *);
	BGL_IMPORT obj_t BGl_modulezd2initializa7ationz75zz__errorz00(long, char *);
	BGL_IMPORT obj_t BGl_loadqz00zz__evalz00(obj_t, obj_t);
	extern obj_t BGl_za2libzd2dirza2zd2zzengine_paramz00;
	static obj_t BGl_cnstzd2initzd2zzinit_extendz00(void);
	static obj_t BGl_libraryzd2moduleszd2initz00zzinit_extendz00(void);
	static obj_t BGl_importedzd2moduleszd2initz00zzinit_extendz00(void);
	static obj_t BGl_gczd2rootszd2initz00zzinit_extendz00(void);
	static obj_t BGl_za2extendzd2tableza2zd2zzinit_extendz00 = BUNSPEC;
	extern obj_t BGl_za2currentzd2passza2zd2zzengine_passz00;
	BGL_IMPORT obj_t BGl_findzd2filezf2pathz20zz__osz00(obj_t, obj_t);
	extern obj_t BGl_verbosez00zztools_speekz00(obj_t, obj_t);
	BGL_IMPORT obj_t BGl_memberz00zz__r4_pairs_and_lists_6_3z00(obj_t, obj_t);
	BGL_IMPORT obj_t BGl_defaultzd2environmentzd2zz__evalz00(void);
	BGL_EXPORTED_DECL obj_t BGl_loadzd2extendzd2zzinit_extendz00(obj_t);
	static obj_t __cnst[1];


	   
		 
		DEFINE_EXPORT_BGL_PROCEDURE(BGl_loadzd2extendzd2envz00zzinit_extendz00,
		BgL_bgl_za762loadza7d2extend1062z00,
		BGl_z62loadzd2extendzb0zzinit_extendz00, 0L, BUNSPEC, 1);
	      DEFINE_STRING(BGl_string1054z00zzinit_extendz00,
		BgL_bgl_string1054za700za7za7i1063za7, "   . ", 5);
	      DEFINE_STRING(BGl_string1055z00zzinit_extendz00,
		BgL_bgl_string1055za700za7za7i1064za7, "failure during prelude hook", 27);
	      DEFINE_STRING(BGl_string1056z00zzinit_extendz00,
		BgL_bgl_string1056za700za7za7i1065za7, ".init", 5);
	      DEFINE_STRING(BGl_string1057z00zzinit_extendz00,
		BgL_bgl_string1057za700za7za7i1066za7, "parse-args", 10);
	      DEFINE_STRING(BGl_string1058z00zzinit_extendz00,
		BgL_bgl_string1058za700za7za7i1067za7, "Can't find extend file", 22);
	      DEFINE_STRING(BGl_string1059z00zzinit_extendz00,
		BgL_bgl_string1059za700za7za7i1068za7, "init_extend", 11);
	      DEFINE_STRING(BGl_string1060z00zzinit_extendz00,
		BgL_bgl_string1060za700za7za7i1069za7, "pass-started ", 13);

/* GC roots registration */
	static obj_t bgl_gc_roots_register()
	{
#if defined( BGL_GC_ROOTS )
#define ADD_ROOT( addr ) (addr > roots_max ? roots_max = addr : (addr < roots_min ? roots_min = addr : 0))
		void *roots_min = (void *) ULONG_MAX, *roots_max = 0;
		   
			 ADD_ROOT((void *) (&BGl_requirezd2initializa7ationz75zzinit_extendz00));
		     ADD_ROOT((void *) (&BGl_za2extendzd2tableza2zd2zzinit_extendz00));
#undef ADD_ROOT
		if   (roots_max > 0)
			     GC_add_roots(roots_min, ((void **) roots_max) + 1);
#endif
		     return BUNSPEC;
	}



/* module-initialization */
	BGL_EXPORTED_DEF obj_t BGl_modulezd2initializa7ationz75zzinit_extendz00(long
		BgL_checksumz00_80, char *BgL_fromz00_81)
	{
		{
			if (CBOOL(BGl_requirezd2initializa7ationz75zzinit_extendz00))
				{
					BGl_requirezd2initializa7ationz75zzinit_extendz00 =
						BBOOL(((bool_t) 0));
					BGl_gczd2rootszd2initz00zzinit_extendz00();
					BGl_libraryzd2moduleszd2initz00zzinit_extendz00();
					BGl_cnstzd2initzd2zzinit_extendz00();
					BGl_importedzd2moduleszd2initz00zzinit_extendz00();
					return BGl_toplevelzd2initzd2zzinit_extendz00();
				}
			else
				{
					return BUNSPEC;
				}
		}

	}



/* library-modules-init */
	obj_t BGl_libraryzd2moduleszd2initz00zzinit_extendz00(void)
	{
		{	/* Init/extend.scm 16 */
			BGl_modulezd2initializa7ationz75zz__readerz00(0L, "init_extend");
			BGl_modulezd2initializa7ationz75zz__r4_ports_6_10_1z00(0L, "init_extend");
			BGl_modulezd2initializa7ationz75zz__errorz00(0L, "init_extend");
			BGl_modulezd2initializa7ationz75zz__evalz00(0L, "init_extend");
			BGl_modulezd2initializa7ationz75zz__osz00(0L, "init_extend");
			BGl_modulezd2initializa7ationz75zz__r4_pairs_and_lists_6_3z00(0L,
				"init_extend");
			BGl_modulezd2initializa7ationz75zz__r4_strings_6_7z00(0L, "init_extend");
			return BUNSPEC;
		}

	}



/* cnst-init */
	obj_t BGl_cnstzd2initzd2zzinit_extendz00(void)
	{
		{	/* Init/extend.scm 16 */
			{	/* Init/extend.scm 16 */
				obj_t BgL_cportz00_69;

				{	/* Init/extend.scm 16 */
					obj_t BgL_stringz00_76;

					BgL_stringz00_76 = BGl_string1060z00zzinit_extendz00;
					{	/* Init/extend.scm 16 */
						obj_t BgL_startz00_77;

						BgL_startz00_77 = BINT(0L);
						{	/* Init/extend.scm 16 */
							obj_t BgL_endz00_78;

							BgL_endz00_78 = BINT(STRING_LENGTH(((obj_t) BgL_stringz00_76)));
							{	/* Init/extend.scm 16 */

								BgL_cportz00_69 =
									BGl_openzd2inputzd2stringz12z12zz__r4_ports_6_10_1z00
									(BgL_stringz00_76, BgL_startz00_77, BgL_endz00_78);
				}}}}
				{
					long BgL_iz00_70;

					BgL_iz00_70 = 0L;
				BgL_loopz00_71:
					if ((BgL_iz00_70 == (-1L)))
						{	/* Init/extend.scm 16 */
							return BUNSPEC;
						}
					else
						{	/* Init/extend.scm 16 */
							{	/* Init/extend.scm 16 */
								obj_t BgL_arg1061z00_72;

								{	/* Init/extend.scm 16 */

									{	/* Init/extend.scm 16 */
										obj_t BgL_locationz00_74;

										BgL_locationz00_74 = BBOOL(((bool_t) 0));
										{	/* Init/extend.scm 16 */

											BgL_arg1061z00_72 =
												BGl_readz00zz__readerz00(BgL_cportz00_69,
												BgL_locationz00_74);
										}
									}
								}
								{	/* Init/extend.scm 16 */
									int BgL_tmpz00_106;

									BgL_tmpz00_106 = (int) (BgL_iz00_70);
									CNST_TABLE_SET(BgL_tmpz00_106, BgL_arg1061z00_72);
							}}
							{	/* Init/extend.scm 16 */
								int BgL_auxz00_75;

								BgL_auxz00_75 = (int) ((BgL_iz00_70 - 1L));
								{
									long BgL_iz00_111;

									BgL_iz00_111 = (long) (BgL_auxz00_75);
									BgL_iz00_70 = BgL_iz00_111;
									goto BgL_loopz00_71;
								}
							}
						}
				}
			}
		}

	}



/* gc-roots-init */
	obj_t BGl_gczd2rootszd2initz00zzinit_extendz00(void)
	{
		{	/* Init/extend.scm 16 */
			return bgl_gc_roots_register();
		}

	}



/* toplevel-init */
	obj_t BGl_toplevelzd2initzd2zzinit_extendz00(void)
	{
		{	/* Init/extend.scm 16 */
			return (BGl_za2extendzd2tableza2zd2zzinit_extendz00 = BNIL, BUNSPEC);
		}

	}



/* load-extend */
	BGL_EXPORTED_DEF obj_t BGl_loadzd2extendzd2zzinit_extendz00(obj_t
		BgL_extendzd2namezd2_3)
	{
		{	/* Init/extend.scm 25 */
			if (CBOOL(BGl_memberz00zz__r4_pairs_and_lists_6_3z00
					(BgL_extendzd2namezd2_3,
						BGl_za2extendzd2tableza2zd2zzinit_extendz00)))
				{	/* Init/extend.scm 26 */
					return BFALSE;
				}
			else
				{	/* Init/extend.scm 26 */
					BGl_za2extendzd2tableza2zd2zzinit_extendz00 =
						MAKE_YOUNG_PAIR(BgL_extendzd2namezd2_3,
						BGl_za2extendzd2tableza2zd2zzinit_extendz00);
					{	/* Init/extend.scm 28 */
						obj_t BgL_fnamez00_14;

						BgL_fnamez00_14 =
							BGl_findzd2filezf2pathz20zz__osz00(BgL_extendzd2namezd2_3,
							BGl_za2libzd2dirza2zd2zzengine_paramz00);
						if (CBOOL(BgL_fnamez00_14))
							{	/* Init/extend.scm 29 */
								{	/* Init/extend.scm 31 */
									obj_t BgL_list1025z00_15;

									{	/* Init/extend.scm 31 */
										obj_t BgL_arg1026z00_16;

										{	/* Init/extend.scm 31 */
											obj_t BgL_arg1027z00_17;

											BgL_arg1027z00_17 =
												MAKE_YOUNG_PAIR(BCHAR(((unsigned char) 10)), BNIL);
											BgL_arg1026z00_16 =
												MAKE_YOUNG_PAIR(BgL_fnamez00_14, BgL_arg1027z00_17);
										}
										BgL_list1025z00_15 =
											MAKE_YOUNG_PAIR(BGl_string1054z00zzinit_extendz00,
											BgL_arg1026z00_16);
									}
									BGl_verbosez00zztools_speekz00(BINT(1L), BgL_list1025z00_15);
								}
								BGl_za2nbzd2errorzd2onzd2passza2zd2zztools_errorz00 = BINT(0L);
								BGl_za2currentzd2passza2zd2zzengine_passz00 = BgL_fnamez00_14;
								{	/* Init/extend.scm 31 */
									obj_t BgL_g1016z00_18;

									BgL_g1016z00_18 = BNIL;
									{
										obj_t BgL_hooksz00_21;
										obj_t BgL_hnamesz00_22;

										BgL_hooksz00_21 = BgL_g1016z00_18;
										BgL_hnamesz00_22 = BNIL;
									BgL_zc3z04anonymousza31028ze3z87_23:
										if (NULLP(BgL_hooksz00_21))
											{	/* Init/extend.scm 31 */
												((obj_t) CNST_TABLE_REF(0));
											}
										else
											{	/* Init/extend.scm 31 */
												bool_t BgL_test1075z00_132;

												{	/* Init/extend.scm 31 */
													obj_t BgL_fun1037z00_30;

													BgL_fun1037z00_30 = CAR(((obj_t) BgL_hooksz00_21));
													BgL_test1075z00_132 =
														CBOOL(BGL_PROCEDURE_CALL0(BgL_fun1037z00_30));
												}
												if (BgL_test1075z00_132)
													{	/* Init/extend.scm 31 */
														obj_t BgL_arg1034z00_27;
														obj_t BgL_arg1035z00_28;

														BgL_arg1034z00_27 = CDR(((obj_t) BgL_hooksz00_21));
														BgL_arg1035z00_28 = CDR(((obj_t) BgL_hnamesz00_22));
														{
															obj_t BgL_hnamesz00_144;
															obj_t BgL_hooksz00_143;

															BgL_hooksz00_143 = BgL_arg1034z00_27;
															BgL_hnamesz00_144 = BgL_arg1035z00_28;
															BgL_hnamesz00_22 = BgL_hnamesz00_144;
															BgL_hooksz00_21 = BgL_hooksz00_143;
															goto BgL_zc3z04anonymousza31028ze3z87_23;
														}
													}
												else
													{	/* Init/extend.scm 31 */
														obj_t BgL_arg1036z00_29;

														BgL_arg1036z00_29 = CAR(((obj_t) BgL_hnamesz00_22));
														BGl_internalzd2errorzd2zztools_errorz00
															(BgL_fnamez00_14,
															BGl_string1055z00zzinit_extendz00,
															BgL_arg1036z00_29);
													}
											}
									}
								}
								{	/* Init/extend.scm 32 */
									obj_t BgL_envz00_34;

									BgL_envz00_34 = BGl_defaultzd2environmentzd2zz__evalz00();
									{	/* Init/extend.scm 32 */

										return
											BGl_loadqz00zz__evalz00(BgL_fnamez00_14, BgL_envz00_34);
									}
								}
							}
						else
							{	/* Init/extend.scm 33 */
								obj_t BgL_fnamez00_35;

								{	/* Init/extend.scm 33 */
									obj_t BgL_arg1051z00_56;

									BgL_arg1051z00_56 =
										string_append(BgL_extendzd2namezd2_3,
										BGl_string1056z00zzinit_extendz00);
									BgL_fnamez00_35 =
										BGl_findzd2filezf2pathz20zz__osz00(BgL_arg1051z00_56,
										BGl_za2libzd2dirza2zd2zzengine_paramz00);
								}
								if (CBOOL(BgL_fnamez00_35))
									{	/* Init/extend.scm 35 */
										{	/* Init/extend.scm 37 */
											obj_t BgL_list1039z00_36;

											{	/* Init/extend.scm 37 */
												obj_t BgL_arg1040z00_37;

												{	/* Init/extend.scm 37 */
													obj_t BgL_arg1041z00_38;

													BgL_arg1041z00_38 =
														MAKE_YOUNG_PAIR(BCHAR(((unsigned char) 10)), BNIL);
													BgL_arg1040z00_37 =
														MAKE_YOUNG_PAIR(BgL_fnamez00_35, BgL_arg1041z00_38);
												}
												BgL_list1039z00_36 =
													MAKE_YOUNG_PAIR(BGl_string1054z00zzinit_extendz00,
													BgL_arg1040z00_37);
											}
											BGl_verbosez00zztools_speekz00(BINT(1L),
												BgL_list1039z00_36);
										}
										BGl_za2nbzd2errorzd2onzd2passza2zd2zztools_errorz00 =
											BINT(0L);
										BGl_za2currentzd2passza2zd2zzengine_passz00 =
											BgL_fnamez00_35;
										{	/* Init/extend.scm 37 */
											obj_t BgL_g1018z00_39;

											BgL_g1018z00_39 = BNIL;
											{
												obj_t BgL_hooksz00_42;
												obj_t BgL_hnamesz00_43;

												BgL_hooksz00_42 = BgL_g1018z00_39;
												BgL_hnamesz00_43 = BNIL;
											BgL_zc3z04anonymousza31042ze3z87_44:
												if (NULLP(BgL_hooksz00_42))
													{	/* Init/extend.scm 37 */
														((obj_t) CNST_TABLE_REF(0));
													}
												else
													{	/* Init/extend.scm 37 */
														bool_t BgL_test1078z00_165;

														{	/* Init/extend.scm 37 */
															obj_t BgL_fun1049z00_51;

															BgL_fun1049z00_51 =
																CAR(((obj_t) BgL_hooksz00_42));
															BgL_test1078z00_165 =
																CBOOL(BGL_PROCEDURE_CALL0(BgL_fun1049z00_51));
														}
														if (BgL_test1078z00_165)
															{	/* Init/extend.scm 37 */
																obj_t BgL_arg1046z00_48;
																obj_t BgL_arg1047z00_49;

																BgL_arg1046z00_48 =
																	CDR(((obj_t) BgL_hooksz00_42));
																BgL_arg1047z00_49 =
																	CDR(((obj_t) BgL_hnamesz00_43));
																{
																	obj_t BgL_hnamesz00_177;
																	obj_t BgL_hooksz00_176;

																	BgL_hooksz00_176 = BgL_arg1046z00_48;
																	BgL_hnamesz00_177 = BgL_arg1047z00_49;
																	BgL_hnamesz00_43 = BgL_hnamesz00_177;
																	BgL_hooksz00_42 = BgL_hooksz00_176;
																	goto BgL_zc3z04anonymousza31042ze3z87_44;
																}
															}
														else
															{	/* Init/extend.scm 37 */
																obj_t BgL_arg1048z00_50;

																BgL_arg1048z00_50 =
																	CAR(((obj_t) BgL_hnamesz00_43));
																BGl_internalzd2errorzd2zztools_errorz00
																	(BgL_fnamez00_35,
																	BGl_string1055z00zzinit_extendz00,
																	BgL_arg1048z00_50);
															}
													}
											}
										}
										{	/* Init/extend.scm 38 */
											obj_t BgL_envz00_55;

											BgL_envz00_55 = BGl_defaultzd2environmentzd2zz__evalz00();
											{	/* Init/extend.scm 38 */

												return
													BGl_loadqz00zz__evalz00(BgL_fnamez00_35,
													BgL_envz00_55);
											}
										}
									}
								else
									{	/* Init/extend.scm 35 */
										return
											BGl_errorz00zz__errorz00
											(BGl_string1057z00zzinit_extendz00,
											BGl_string1058z00zzinit_extendz00,
											BgL_extendzd2namezd2_3);
									}
							}
					}
				}
		}

	}



/* &load-extend */
	obj_t BGl_z62loadzd2extendzb0zzinit_extendz00(obj_t BgL_envz00_67,
		obj_t BgL_extendzd2namezd2_68)
	{
		{	/* Init/extend.scm 25 */
			return BGl_loadzd2extendzd2zzinit_extendz00(BgL_extendzd2namezd2_68);
		}

	}



/* object-init */
	obj_t BGl_objectzd2initzd2zzinit_extendz00(void)
	{
		{	/* Init/extend.scm 16 */
			return BUNSPEC;
		}

	}



/* generic-init */
	obj_t BGl_genericzd2initzd2zzinit_extendz00(void)
	{
		{	/* Init/extend.scm 16 */
			return BUNSPEC;
		}

	}



/* method-init */
	obj_t BGl_methodzd2initzd2zzinit_extendz00(void)
	{
		{	/* Init/extend.scm 16 */
			return BUNSPEC;
		}

	}



/* imported-modules-init */
	obj_t BGl_importedzd2moduleszd2initz00zzinit_extendz00(void)
	{
		{	/* Init/extend.scm 16 */
			BGl_modulezd2initializa7ationz75zztools_speekz00(61247943L,
				BSTRING_TO_STRING(BGl_string1059z00zzinit_extendz00));
			BGl_modulezd2initializa7ationz75zztools_errorz00(300504031L,
				BSTRING_TO_STRING(BGl_string1059z00zzinit_extendz00));
			BGl_modulezd2initializa7ationz75zzengine_passz00(373082237L,
				BSTRING_TO_STRING(BGl_string1059z00zzinit_extendz00));
			return
				BGl_modulezd2initializa7ationz75zzengine_paramz00(161876678L,
				BSTRING_TO_STRING(BGl_string1059z00zzinit_extendz00));
		}

	}

#ifdef __cplusplus
}
#endif
